@@ -3,7 +3,7 @@ use Mojo::Base 'Minion::Backend';
 
 use Carp 'croak';
 use Mojo::IOLoop;
-use Mojo::Pg 2.18;
+use Mojo::Pg 2.33;
 use Sys::Hostname 'hostname';
 
 has 'pg';
@@ -52,7 +52,8 @@ sub finish_job { shift->_update(0, @_) }
 sub job_info {
   shift->pg->db->query(
     'select id, args, attempts,
-       array(select id from minion_jobs where j.id = any(parents)) as children,
+       array(select id from minion_jobs where parents @> ARRAY[j.id])
+         as children,
        extract(epoch from created) as created,
        extract(epoch from delayed) as delayed,
        extract(epoch from finished) as finished, parents, priority, queue,
@@ -147,7 +148,7 @@ sub repair {
      set finished = now(), result = to_json('Parent went away'::text),
        state = 'failed'
      where parents <> '{}' and cardinality(parents) <> (
-       select count(*) from minion_jobs where id = any(j.parents)
+       select count(*) from minion_jobs where j.parents @> ARRAY[id]
      ) and state = 'inactive'"
   );
 
@@ -156,7 +157,7 @@ sub repair {
     "delete from minion_jobs as j
      where finished <= now() - interval '1 second' * ? and not exists (
        select 1 from minion_jobs
-       where j.id = any(parents) and state <> 'finished'
+       where parents @> ARRAY[j.id] and state <> 'finished'
      ) and state = 'finished'", $minion->remove_after
   );
 }
@@ -228,7 +229,7 @@ sub _try {
        select id from minion_jobs as j
        where delayed <= now() and (parents = '{}' or cardinality(parents) = (
          select count(*) from minion_jobs
-         where id = any(j.parents) and state = 'finished'
+         where j.parents @> ARRAY[id] and state = 'finished'
        )) and queue = any(?) and state = 'inactive' and task = any(?)
        order by priority desc, id
        limit 1
@@ -388,7 +389,7 @@ transitioned to the state C<finished> before it can be processed.
 
   priority => 5
 
-Job priority, defaults to C<0>.
+Job priority, defaults to C<0>. Jobs with a higher priority get performed first.
 
 =item queue
 
@@ -848,3 +849,6 @@ create index on minion_jobs (state, priority desc, id);
 -- 12 up
 alter table minion_workers add column inbox jsonb
   check(jsonb_typeof(inbox) = 'array') default '[]';
+
+-- 13 up
+create index on minion_jobs using gin (parents);
